package com.jeeplus.modules.filing.earlyEngineering.web;

import com.google.common.collect.Lists;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.common.utils.excel.ImportExcel;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.filing.earlyEngineering.entity.ApplicationFor;
import com.jeeplus.modules.filing.earlyEngineering.service.ApplicationForService;
import com.jeeplus.modules.filing.filingImages.service.FilingImagesService;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 报建审批Controller
 * @author qy
 * @version 2021-03-24
 */
@Controller
@RequestMapping(value = "${adminPath}/filing/applicationFor")
public class ApplicationForController extends BaseController {

	@Autowired
	private ApplicationForService applicationForService;

	@Autowired
	private FilingImagesService filingImagesService;

	@ModelAttribute
	public ApplicationFor get(@RequestParam(required=false) String id) {
		ApplicationFor entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = applicationForService.get(id);
		}
		if (entity == null){
			entity = new ApplicationFor();
		}
		return entity;
	}
	
	/**
	 * 报建审批列表页面
	 */
	@RequiresPermissions("test:filing:applicationFor:list")
	@RequestMapping(value = {"list", ""})
	public String list(ApplicationFor applicationFor, Model model) {
		model.addAttribute("applicationFor", applicationFor);
		return "modules/filing/applicationFor/applicationForList";
	}
	
		/**
	 * 报建审批列表数据
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:applicationFor:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(ApplicationFor applicationFor, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<ApplicationFor> page = applicationForService.findPage(new Page<ApplicationFor>(request, response,-1), applicationFor);
		return getBootstrapData(page);
	}

	/**
	 * 查看，增加,报建审批表单页面
	 */
	@RequiresPermissions(value={"test:filing:applicationFor:view","test:filing:applicationFor:add","test:filing:applicationFor:edit"},logical=Logical.OR)
	@RequestMapping(value = "form")
	public String form(ApplicationFor applicationFor, Model model) {
		model.addAttribute("applicationFor", applicationFor);
		return "modules/filing/applicationFor/applicationForForm";
	}

	
	/**
	 * 保存报建审批
	 */
	@ResponseBody
	@RequiresPermissions(value={"test:filing:applicationFor:add","test:filing:applicationFor:edit"},logical=Logical.OR)
	@RequestMapping(value = "save")
	public AjaxJson save(ApplicationFor applicationFor, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(applicationFor);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		applicationForService.save(applicationFor);//保存
		j.setSuccess(true);
		j.setMsg("保存报建审批成功");
		return j;
	}

	/**
	 * 保存报建审批
	 */
	@ResponseBody
	@RequiresPermissions(value={"test:filing:applicationFor:add","test:filing:applicationFor:edit"},logical=Logical.OR)
	@RequestMapping(value = "updateSave")
	public AjaxJson updateSave(ApplicationFor applicationFor, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(applicationFor);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		applicationForService.save(applicationFor);//保存
		j.setSuccess(true);
		j.setMsg("保存报建审批成功");
		return j;
	}


	/**
	 * 删除报建审批
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:applicationFor:del")
	@RequestMapping(value = "delete")
	public AjaxJson delete(ApplicationFor applicationFor) {
		AjaxJson j = new AjaxJson();
		applicationForService.delete(applicationFor);
		j.setMsg("删除报建审批成功");
		return j;
	}
	
	/**
	 * 批量删除报建审批
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:applicationFor:del")
	@RequestMapping(value = "deleteAll")
	public AjaxJson deleteAll(String ids) {
		AjaxJson j = new AjaxJson();
		String idArray[] =ids.split(",");
		for(String id : idArray){
			applicationForService.delete(applicationForService.get(id));
		}
		j.setMsg("删除报建审批成功");
		return j;
	}
	
	/**
	 * 导出excel文件
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:applicationFor:export")
    @RequestMapping(value = "export")
    public AjaxJson exportFile(ApplicationFor applicationFor, HttpServletRequest request, HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "报建审批"+DateUtils.getDate("yyyyMMddHHmmss")+".xlsx";
			//查询所有父级的信息
			List<ApplicationFor> list = applicationForService.findList(applicationFor);
			List<ApplicationFor> returnList = new ArrayList<>();
			//根据父级，查询所有子级的信息
			for (ApplicationFor a :
					list) {
				List<ApplicationFor> childList = applicationForService.findChildList(a);
				returnList.add(a);
				for (ApplicationFor b :
						childList) {
					returnList.add(b);
				}
			}
    		new ExportExcel("报建审批", ApplicationFor.class).setDataList(returnList).write(response, fileName).dispose();
    		j.setSuccess(true);
    		j.setMsg("导出成功！");
    		return j;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导出报建审批记录失败！失败信息："+e.getMessage());
		}
			return j;
    }

    
    @ResponseBody
    @RequestMapping(value = "detail")
	public Map<String, Object> detail(ApplicationFor applicationFor, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<ApplicationFor> page = applicationForService.findChildPage(new Page<ApplicationFor>(request, response), applicationFor);
		return getBootstrapData(page);
	}
	

	/**
	 * 导入Excel数据
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:applicationFor:import")
    @RequestMapping(value = "import")
   	public AjaxJson importFile(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
		AjaxJson j = new AjaxJson();
		try {
			ImportExcel ei = new ImportExcel(file, 1, 0);
			List<ApplicationFor> list = ei.getDataList(ApplicationFor.class);
			for (ApplicationFor applicationFor :
					list) {
				applicationForService.save(applicationFor);
			}
			j.setMsg( "已成功导入条报建审批记录");
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入报建审批失败！失败信息："+e.getMessage());
		}
		return j;
    }
	
	/**
	 * 下载导入报建审批数据模板
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:applicationFor:import")
    @RequestMapping(value = "import/template")
     public AjaxJson importFileTemplate(HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "报建审批数据导入模板.xlsx";
    		List<ApplicationFor> list = Lists.newArrayList(); 
    		new ExportExcel("报建审批数据", ApplicationFor.class, 1).setDataList(list).write(response, fileName).dispose();
    		return null;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg( "导入模板下载失败！失败信息："+e.getMessage());
		}
		return j;
    }
	

}