package com.jeeplus.modules.filing.earlyEngineering.web;

import com.google.common.collect.Lists;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.common.utils.excel.ImportExcel;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.filing.constructionStage.entity.ConstructionStage;
import com.jeeplus.modules.filing.earlyEngineering.entity.BiddingContract;
import com.jeeplus.modules.filing.earlyEngineering.service.BiddingContractService;
import com.jeeplus.modules.filing.filingImages.service.FilingImagesService;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 招标与合同管理Controller
 * @author qy
 * @version 2021-03-24
 */
@Controller
@RequestMapping(value = "${adminPath}/filing/biddingContract")
public class BiddingContractController extends BaseController {

	@Autowired
	private BiddingContractService biddingContractService;

	@Autowired
	private FilingImagesService filingImagesService;

	@ModelAttribute
	public BiddingContract get(@RequestParam(required=false) String id) {
		BiddingContract entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = biddingContractService.get(id);
		}
		if (entity == null){
			entity = new BiddingContract();
		}
		return entity;
	}
	
	/**
	 * 招标与合同管理列表页面
	 */
	@RequiresPermissions("test:filing:biddingContract:list")
	@RequestMapping(value = {"list", ""})
	public String list(BiddingContract biddingContract, Model model) {
		model.addAttribute("biddingContract", biddingContract);
		return "modules/filing/biddingContract/biddingContractList";
	}
	
		/**
	 * 招标与合同管理列表数据
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:biddingContract:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(BiddingContract biddingContract, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<BiddingContract> page = biddingContractService.findPage(new Page<BiddingContract>(request, response,-1), biddingContract);
		return getBootstrapData(page);
	}

	/**
	 * 查看，增加,招标与合同管理表单页面
	 */
	@RequiresPermissions(value={"test:filing:biddingContract:view","test:filing:biddingContract:add","test:filing:biddingContract:edit"},logical=Logical.OR)
	@RequestMapping(value = "form")
	public String form(BiddingContract biddingContract, Model model) {
		model.addAttribute("biddingContract", biddingContract);
		return "modules/filing/biddingContract/biddingContractForm";
	}

	
	/**
	 * 保存招标与合同管理
	 */
	@ResponseBody
	@RequiresPermissions(value={"test:filing:biddingContract:add","test:filing:biddingContract:edit"},logical=Logical.OR)
	@RequestMapping(value = "save")
	public AjaxJson save(BiddingContract biddingContract, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(biddingContract);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		biddingContractService.save(biddingContract);//保存
		j.setSuccess(true);
		j.setMsg("保存招标与合同管理成功");
		return j;
	}

	/**
	 * 保存招标与合同管理
	 */
	@ResponseBody
	@RequiresPermissions(value={"test:filing:biddingContract:add","test:filing:biddingContract:edit"},logical=Logical.OR)
	@RequestMapping(value = "updateSave")
	public AjaxJson updateSave(BiddingContract biddingContract, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(biddingContract);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		biddingContractService.save(biddingContract);//保存
		j.setSuccess(true);
		j.setMsg("保存招标与合同管理成功");
		return j;
	}


	/**
	 * 删除招标与合同管理
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:biddingContract:del")
	@RequestMapping(value = "delete")
	public AjaxJson delete(BiddingContract biddingContract) {
		AjaxJson j = new AjaxJson();
		biddingContractService.delete(biddingContract);
		j.setMsg("删除招标与合同管理成功");
		return j;
	}
	
	/**
	 * 批量删除招标与合同管理
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:biddingContract:del")
	@RequestMapping(value = "deleteAll")
	public AjaxJson deleteAll(String ids) {
		AjaxJson j = new AjaxJson();
		String idArray[] =ids.split(",");
		for(String id : idArray){
			biddingContractService.delete(biddingContractService.get(id));
		}
		j.setMsg("删除招标与合同管理成功");
		return j;
	}
	
	/**
	 * 导出excel文件
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:biddingContract:export")
    @RequestMapping(value = "export")
    public AjaxJson exportFile(BiddingContract biddingContract, HttpServletRequest request, HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "招标与合同管理"+DateUtils.getDate("yyyyMMddHHmmss")+".xlsx";
			//查询所有父级的信息
			List<BiddingContract> list = biddingContractService.findList(biddingContract);
			List<BiddingContract> returnList = new ArrayList<>();
			//根据父级，查询所有子级的信息
			for (BiddingContract a :
					list) {
				List<BiddingContract> childList = biddingContractService.findChildList(a);
				returnList.add(a);
				for (BiddingContract b :
						childList) {
					returnList.add(b);
				}
			}
    		new ExportExcel("招标与合同管理", BiddingContract.class).setDataList(returnList).write(response, fileName).dispose();
    		j.setSuccess(true);
    		j.setMsg("导出成功！");
    		return j;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导出招标与合同管理记录失败！失败信息："+e.getMessage());
		}
			return j;
    }

    
    @ResponseBody
    @RequestMapping(value = "detail")
	public Map<String, Object> detail(BiddingContract biddingContract, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<BiddingContract> page = biddingContractService.findChildPage(new Page<BiddingContract>(request, response), biddingContract);
		return getBootstrapData(page);
	}
	

	/**
	 * 导入Excel数据
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:biddingContract:import")
    @RequestMapping(value = "import")
   	public AjaxJson importFile(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
		AjaxJson j = new AjaxJson();
		try {
			ImportExcel ei = new ImportExcel(file, 1, 0);
			List<BiddingContract> list = ei.getDataList(BiddingContract.class);
			for (BiddingContract biddingContract :
					list) {
				biddingContractService.save(biddingContract);
			}
			j.setMsg( "已成功导入条招标与合同管理记录");
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入招标与合同管理失败！失败信息："+e.getMessage());
		}
		return j;
    }
	
	/**
	 * 下载导入招标与合同管理数据模板
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:biddingContract:import")
    @RequestMapping(value = "import/template")
     public AjaxJson importFileTemplate(HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "招标与合同管理数据导入模板.xlsx";
    		List<BiddingContract> list = Lists.newArrayList(); 
    		new ExportExcel("招标与合同管理数据", BiddingContract.class, 1).setDataList(list).write(response, fileName).dispose();
    		return null;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg( "导入模板下载失败！失败信息："+e.getMessage());
		}
		return j;
    }
	

}