package com.jeeplus.modules.filing.earlyEngineering.web;

import com.google.common.collect.Lists;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.common.utils.excel.ImportExcel;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.filing.constructionStage.entity.ConstructionStage;
import com.jeeplus.modules.filing.earlyEngineering.entity.DesignStage;
import com.jeeplus.modules.filing.earlyEngineering.service.DesignStageService;
import com.jeeplus.modules.filing.filingImages.entity.FilingImages;
import com.jeeplus.modules.filing.filingImages.service.FilingImagesService;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * 初设阶段Controller
 * @author qy
 * @version 2021-03-24
 */
@Controller
@RequestMapping(value = "${adminPath}/filing/designStage")
public class DesignStageController extends BaseController {

	@Autowired
	private DesignStageService designStageService;

	@Autowired
	private FilingImagesService filingImagesService;

	@ModelAttribute
	public DesignStage get(@RequestParam(required=false) String id) {
		DesignStage entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = designStageService.get(id);
		}
		if (entity == null){
			entity = new DesignStage();
		}
		return entity;
	}
	
	/**
	 * 初设阶段列表页面
	 */
	@RequiresPermissions("test:filing:designStage:list")
	@RequestMapping(value = {"list", ""})
	public String list(DesignStage designStage, Model model) {
		model.addAttribute("designStage", designStage);
		return "modules/filing/designStage/designStageList";
	}
	
		/**
	 * 初设阶段列表数据
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:designStage:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(DesignStage designStage, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<DesignStage> page = designStageService.findPage(new Page<DesignStage>(request, response,-1), designStage);
		return getBootstrapData(page);
	}

	/**
	 * 查看，增加,初设阶段表单页面
	 */
	@RequiresPermissions(value={"test:filing:designStage:view","test:filing:designStage:add","test:filing:designStage:edit"},logical=Logical.OR)
	@RequestMapping(value = "form")
	public String form(DesignStage designStage, Model model) {
		model.addAttribute("designStage", designStage);
		return "modules/filing/designStage/designStageForm";
	}

	
	/**
	 * 保存初设阶段
	 */
	@ResponseBody
	@RequiresPermissions(value={"test:filing:designStage:add","test:filing:designStage:edit"},logical=Logical.OR)
	@RequestMapping(value = "save")
	public AjaxJson save(DesignStage designStage, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(designStage);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		designStageService.save(designStage);//保存
		j.setSuccess(true);
		j.setMsg("保存初设阶段成功");
		return j;
	}

	/**
	 * 保存初设阶段
	 */
	@ResponseBody
	@RequiresPermissions(value={"test:filing:designStage:add","test:filing:designStage:edit"},logical=Logical.OR)
	@RequestMapping(value = "updateSave")
	public AjaxJson updateSave(DesignStage designStage, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(designStage);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		designStageService.save(designStage);//保存
		j.setSuccess(true);
		j.setMsg("保存初设阶段成功");
		return j;
	}


	/**
	 * 删除初设阶段
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:designStage:del")
	@RequestMapping(value = "delete")
	public AjaxJson delete(DesignStage designStage) {
		AjaxJson j = new AjaxJson();
		designStageService.delete(designStage);
		j.setMsg("删除初设阶段成功");
		return j;
	}
	
	/**
	 * 批量删除初设阶段
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:designStage:del")
	@RequestMapping(value = "deleteAll")
	public AjaxJson deleteAll(String ids) {
		AjaxJson j = new AjaxJson();
		String idArray[] =ids.split(",");
		for(String id : idArray){
			designStageService.delete(designStageService.get(id));
		}
		j.setMsg("删除初设阶段成功");
		return j;
	}
	
	/**
	 * 导出excel文件
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:designStage:export")
    @RequestMapping(value = "export")
    public AjaxJson exportFile(DesignStage designStage, HttpServletRequest request, HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "初设阶段"+DateUtils.getDate("yyyyMMddHHmmss")+".xlsx";
			//查询所有父级的信息
			List<DesignStage> list = designStageService.findList(designStage);
			List<DesignStage> returnList = new ArrayList<>();
			//根据父级，查询所有子级的信息
			for (DesignStage a :
					list) {
				List<DesignStage> childList = designStageService.findChildList(a);
				returnList.add(a);
				for (DesignStage b :
						childList) {
					returnList.add(b);
				}
			}
    		new ExportExcel("初设阶段", DesignStage.class).setDataList(returnList).write(response, fileName).dispose();
    		j.setSuccess(true);
    		j.setMsg("导出成功！");
    		return j;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导出初设阶段记录失败！失败信息："+e.getMessage());
		}
			return j;
    }

    
    @ResponseBody
    @RequestMapping(value = "detail")
	public Map<String, Object> detail(DesignStage designStage, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<DesignStage> page = designStageService.findChildPage(new Page<DesignStage>(request, response), designStage);
		return getBootstrapData(page);
	}
	

	/**
	 * 导入Excel数据
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:designStage:import")
    @RequestMapping(value = "import")
   	public AjaxJson importFile(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
		AjaxJson j = new AjaxJson();
		try {
			ImportExcel ei = new ImportExcel(file, 1, 0);
			List<DesignStage> list = ei.getDataList(DesignStage.class);
			for (DesignStage designStage :
					list) {
				designStageService.save(designStage);
			}
			j.setMsg( "已成功导入条初设阶段记录");
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入初设阶段失败！失败信息："+e.getMessage());
		}
		return j;
    }
	
	/**
	 * 下载导入初设阶段数据模板
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:designStage:import")
    @RequestMapping(value = "import/template")
     public AjaxJson importFileTemplate(HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "初设阶段数据导入模板.xlsx";
    		List<DesignStage> list = Lists.newArrayList(); 
    		new ExportExcel("初设阶段数据", DesignStage.class, 1).setDataList(list).write(response, fileName).dispose();
    		return null;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg( "导入模板下载失败！失败信息："+e.getMessage());
		}
		return j;
    }
	

}