package com.jeeplus.modules.filing.earlyEngineering.web;

import com.google.common.collect.Lists;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.common.utils.excel.ImportExcel;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.filing.constructionStage.entity.ConstructionStage;
import com.jeeplus.modules.filing.earlyEngineering.entity.ReviewStage;
import com.jeeplus.modules.filing.earlyEngineering.service.ReviewStageService;
import com.jeeplus.modules.filing.filingImages.service.FilingImagesService;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 批概阶段Controller
 * @author qy
 * @version 2021-03-24
 */
@Controller
@RequestMapping(value = "${adminPath}/filing/reviewStage")
public class ReviewStageController extends BaseController {

	@Autowired
	private ReviewStageService reviewStageService;

	@Autowired
	private FilingImagesService filingImagesService;

	@ModelAttribute
	public ReviewStage get(@RequestParam(required=false) String id) {
		ReviewStage entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = reviewStageService.get(id);
		}
		if (entity == null){
			entity = new ReviewStage();
		}
		return entity;
	}
	
	/**
	 * 批概阶段列表页面
	 */
	@RequiresPermissions("test:filing:reviewStage:list")
	@RequestMapping(value = {"list", ""})
	public String list(ReviewStage reviewStage, Model model) {
		model.addAttribute("reviewStage", reviewStage);
		return "modules/filing/reviewStage/reviewStageList";
	}
	
		/**
	 * 批概阶段列表数据
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:reviewStage:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(ReviewStage reviewStage, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<ReviewStage> page = reviewStageService.findPage(new Page<ReviewStage>(request, response,-1), reviewStage);
		return getBootstrapData(page);
	}

	/**
	 * 查看，增加,批概阶段表单页面
	 */
	@RequiresPermissions(value={"test:filing:reviewStage:view","test:filing:reviewStage:add","test:filing:reviewStage:edit"},logical=Logical.OR)
	@RequestMapping(value = "form")
	public String form(ReviewStage reviewStage, Model model) {
		model.addAttribute("reviewStage", reviewStage);
		return "modules/filing/reviewStage/reviewStageForm";
	}

	
	/**
	 * 保存批概阶段
	 */
	@ResponseBody
	@RequiresPermissions(value={"test:filing:reviewStage:add","test:filing:reviewStage:edit"},logical=Logical.OR)
	@RequestMapping(value = "save")
	public AjaxJson save(ReviewStage reviewStage, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(reviewStage);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		reviewStageService.save(reviewStage);//保存
		j.setSuccess(true);
		j.setMsg("保存批概阶段成功");
		return j;
	}

	/**
	 * 保存批概阶段
	 */
	@ResponseBody
	@RequiresPermissions(value={"test:filing:reviewStage:add","test:filing:reviewStage:edit"},logical=Logical.OR)
	@RequestMapping(value = "updateSave")
	public AjaxJson updateSave(ReviewStage reviewStage, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(reviewStage);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		reviewStageService.save(reviewStage);//保存
		j.setSuccess(true);
		j.setMsg("保存批概阶段成功");
		return j;
	}


	/**
	 * 删除批概阶段
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:reviewStage:del")
	@RequestMapping(value = "delete")
	public AjaxJson delete(ReviewStage reviewStage) {
		AjaxJson j = new AjaxJson();
		reviewStageService.delete(reviewStage);
		j.setMsg("删除批概阶段成功");
		return j;
	}
	
	/**
	 * 批量删除批概阶段
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:reviewStage:del")
	@RequestMapping(value = "deleteAll")
	public AjaxJson deleteAll(String ids) {
		AjaxJson j = new AjaxJson();
		String idArray[] =ids.split(",");
		for(String id : idArray){
			reviewStageService.delete(reviewStageService.get(id));
		}
		j.setMsg("删除批概阶段成功");
		return j;
	}
	
	/**
	 * 导出excel文件
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:reviewStage:export")
    @RequestMapping(value = "export")
    public AjaxJson exportFile(ReviewStage reviewStage, HttpServletRequest request, HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "批概阶段"+DateUtils.getDate("yyyyMMddHHmmss")+".xlsx";
			//查询所有父级的信息
			List<ReviewStage> list = reviewStageService.findList(reviewStage);
			List<ReviewStage> returnList = new ArrayList<>();
			//根据父级，查询所有子级的信息
			for (ReviewStage a :
					list) {
				List<ReviewStage> childList = reviewStageService.findChildList(a);
				returnList.add(a);
				for (ReviewStage b :
						childList) {
					returnList.add(b);
				}
			}
    		new ExportExcel("批概阶段", ReviewStage.class).setDataList(returnList).write(response, fileName).dispose();
    		j.setSuccess(true);
    		j.setMsg("导出成功！");
    		return j;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导出批概阶段记录失败！失败信息："+e.getMessage());
		}
			return j;
    }

    
    @ResponseBody
    @RequestMapping(value = "detail")
	public Map<String, Object> detail(ReviewStage reviewStage, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<ReviewStage> page = reviewStageService.findChildPage(new Page<ReviewStage>(request, response), reviewStage);
		return getBootstrapData(page);
	}
	

	/**
	 * 导入Excel数据
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:reviewStage:import")
    @RequestMapping(value = "import")
   	public AjaxJson importFile(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
		AjaxJson j = new AjaxJson();
		try {
			ImportExcel ei = new ImportExcel(file, 1, 0);
			List<ReviewStage> list = ei.getDataList(ReviewStage.class);
			for (ReviewStage reviewStage :
					list) {
				reviewStageService.save(reviewStage);
			}
			j.setMsg( "已成功导入条批概阶段记录");
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入批概阶段失败！失败信息："+e.getMessage());
		}
		return j;
    }
	
	/**
	 * 下载导入批概阶段数据模板
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:reviewStage:import")
    @RequestMapping(value = "import/template")
     public AjaxJson importFileTemplate(HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "批概阶段数据导入模板.xlsx";
    		List<ReviewStage> list = Lists.newArrayList(); 
    		new ExportExcel("批概阶段数据", ReviewStage.class, 1).setDataList(list).write(response, fileName).dispose();
    		return null;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg( "导入模板下载失败！失败信息："+e.getMessage());
		}
		return j;
    }
	

}