/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.sg.balancedlibrary.materialQuota.web;

import com.google.common.collect.Lists;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.utils.ImportUtil;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.entity.LiKuResourcePool;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.service.LiKuResourcePoolService;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.utils.LiKuUtils;
import com.jeeplus.modules.sg.balancedlibrary.materialQuota.entity.MaterialQuota;
import com.jeeplus.modules.sg.balancedlibrary.materialQuota.service.MaterialQuotaService;
import org.apache.poi.ss.usermodel.Row;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.ConstraintViolationException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * 物料限额Controller
 * @author lgf
 * @version 2018-06-12
 */
@Controller
@RequestMapping(value = "${adminPath}/materialQuota")
public class MaterialQuotaController extends BaseController {

	@Autowired
	private MaterialQuotaService service;



	@ModelAttribute
	public MaterialQuota get(@RequestParam(required=false) String id) {
		MaterialQuota entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = service.get(id);
		}
		if (entity == null){
			entity = new MaterialQuota();
		}
		return entity;
	}
	
	/**
	 * 物料限额列表页面
	 */
	@RequiresPermissions("sg:balancedlibrary:materialQuota:list")
	@RequestMapping(value = "list")
	public String list(MaterialQuota entity, Model model) {
		model.addAttribute("entity", entity);
		return "modules/sg/balancedlibrary/materialQuota/materialQuotaList";
	}
	
		/**
	 * 物料限额列表数据
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:materialQuota:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(MaterialQuota entity, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<MaterialQuota> page = service.findPage(new Page<MaterialQuota>(request, response), entity);
		return getBootstrapData(page);
	}

	
	/**
	 * 批量删除物料限额
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:materialQuota:del")
	@RequestMapping(value = "deleteAll")
	public AjaxJson deleteAll(String ids) {
		AjaxJson j = new AjaxJson();
		String idArr[] =ids.split(",");
		List<String> idList = Arrays.asList(idArr);
		service.deleteList(idList);
		j.setMsg("删除物料限额成功");
		return j;
	}
	
	/**
	 * 导出excel文件
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:materialQuota:export")
    @RequestMapping(value = "export")
    public AjaxJson exportFile(MaterialQuota entity, HttpServletRequest request, HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "物料限额表"+DateUtils.getDate("yyyyMMddHHmmss")+".xlsx";
            Page<MaterialQuota> page = service.findPage(new Page<MaterialQuota>(request, response, -1), entity);
    		new ExportExcel("", MaterialQuota.class).setDataList(page.getList()).write(response, fileName).dispose();
    		j.setSuccess(true);
    		j.setMsg("导出成功！");
    		return j;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导出物料限额表失败！失败信息："+e.getMessage());
		}
			return j;
    }

	/**
	 * 物料限额-导入Excel数据
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:materialQuota:import")
    @RequestMapping(value = "import")
   	public AjaxJson importFile(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
		AjaxJson j = new AjaxJson();
		try {
			ImportUtil ei = new ImportUtil(file,0,0);
			List<MaterialQuota> list = ei.getDataList(MaterialQuota.class);
			if (list.size() > 0) {
				//物资限额每次重新导入数据，将原有数据清空
				service.fullReplace(list);
				j.setMsg("已成功导入 " + list.size() + " 条物料限额记录");
			}
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入物料限额失败！失败信息："+e.getMessage());
		}
		return j;
    }



	/**
	 * 下载导入物料限额数据模板
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:materialQuota:import")
    @RequestMapping(value = "import/template")
     public AjaxJson importFileTemplate(HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "物料限额数据导入模板.xlsx";
    		List<MaterialQuota> list = Lists.newArrayList();
    		new ExportExcel("", MaterialQuota.class, 1).setDataList(list).write(response, fileName).dispose();
    		return null;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg( "导入模板下载失败！失败信息："+e.getMessage());
		}
		return j;
    }

}