/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.sg.balancedlibrary.onPassageMaterials.web;


import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.common.utils.excel.ImportExcel;
import com.jeeplus.modules.sg.balancedlibrary.onPassageMaterials.entity.MaterialInformation;
import com.jeeplus.modules.sg.balancedlibrary.onPassageMaterials.entity.OnPassageMaterials;
import com.jeeplus.modules.sg.balancedlibrary.onPassageMaterials.service.OnPassageMaterialsService;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.sg.balancedlibrary.reportPerson.entity.ReportPerson;
import com.jeeplus.modules.sg.balancedlibrary.reportPerson.mapper.ReportPersonMapper;
import com.jeeplus.modules.sg.balancedlibrary.reportPerson.service.ReportPersonService;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.*;

/**
 * 在途物资Controller
 *
 * @author 徐滕
 * @version 1.0
 */
@Controller
@RequestMapping(value = "${adminPath}/onPassageMaterials")
public class OnPassageMaterialsController extends BaseController {

    @Autowired
    private OnPassageMaterialsService service;
    @Autowired
    private ReportPersonService reportPersonService;

    @ModelAttribute
    public OnPassageMaterials get(@RequestParam(required = false) String id) {
        OnPassageMaterials entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = service.get(id);
        }
        if (entity == null) {
            entity = new OnPassageMaterials();
        }
        return entity;
    }

    /**
     * 物料替换列表页面
     */
    @RequiresPermissions("sg:balancedlibrary:ReplaceMaterial:list")
    @RequestMapping(value = "list")
    public String list(OnPassageMaterials entity, Model model) {
        model.addAttribute("entity", entity);
        return "modules/sg/balancedlibrary/onPassageMaterials/onPassageMaterialsList";
    }


    /**
     * 在途物资-导入Excel数据
     */
    @ResponseBody
    @PostMapping("import")
    public AjaxJson importFile(@RequestParam("file") MultipartFile[] file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson ajaxJson = new AjaxJson();

        try {
            //获取两张excel表
            ImportExcel onPassageMaterialsFile = new ImportExcel(file[0], 1, 0);
            ImportExcel materialInformationFile = new ImportExcel(file[1], 1, 0);
            //转换为集合
            List<OnPassageMaterials> onPassageMaterialsList = onPassageMaterialsFile.getDataList(OnPassageMaterials.class);
            List<MaterialInformation> materialInformationList = materialInformationFile.getDataList(MaterialInformation.class);

            service.comparativeData(onPassageMaterialsList,materialInformationList);

            /***********************************************/
            String fileName = "项目物资需求表" + DateUtils.getDate("yyyyMMddHHmmss") + ".xlsx";
            new ExportExcel("", MaterialInformation.class).setDataList(materialInformationList).write(response, fileName).dispose();

        } catch (InvalidFormatException | IOException | InstantiationException | IllegalAccessException e) {
            e.printStackTrace();
        }
        return ajaxJson;
    }


}