

package com.jeeplus.modules.sg.balancedlibrary.planSummary.service;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.sg.balancedlibrary.planSummary.entity.AgriculturalDistributionNetwork;
import com.jeeplus.modules.sg.balancedlibrary.planSummary.entity.ProcessTracking;
import com.jeeplus.modules.sg.balancedlibrary.planSummary.mapper.PlanSummaryMapper;
import com.jeeplus.modules.sg.balancedlibrary.planSummary.vo.PlanSummary;
import com.jeeplus.modules.sg.balancedlibrary.reportPerson.entity.ReportPerson;
import com.jeeplus.modules.sg.balancedlibrary.reportPerson.mapper.ReportPersonMapper;
import com.jeeplus.modules.sys.utils.DictUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicReference;

/**
 * @author 杜
 */
@Service
@Transactional(readOnly = true)
public class PlanSummaryService extends CrudService<PlanSummaryMapper, AgriculturalDistributionNetwork> {
    @Autowired
    private ReportPersonMapper reportPersonMapper;


    public List<PlanSummary>  importFile(List<AgriculturalDistributionNetwork> agriculturalDistributionNetworkList, List<ProcessTracking> processTrackingList) {
        //返回结果
        List<PlanSummary> planSummaryList = new ArrayList<>();

        //配农网
        Map<String, BigDecimal> agriculturalDistributionNetworkMap = new HashMap<>();

        //跟踪表
        Map<String, BigDecimal> processTrackingMap = new HashMap<>();

        //提报人
        Map<String, String> reportPersonMap = getPerson();

        // 去重统计各个部门需求数量(配农网)
        agriculturalDistributionNetworkList.forEach(agriculturalDistributionNetwork -> {
            //物料编码+提报人
            String key = agriculturalDistributionNetwork.getRequiredMaterialCode() + "-" +
                    reportPersonMap.get(agriculturalDistributionNetwork.getPlanSubmitter());
            //如果包含key
            if (agriculturalDistributionNetworkMap.containsKey(key)) {
                agriculturalDistributionNetworkMap.put(key,agriculturalDistributionNetworkMap.get(key).
                        add(new BigDecimal(agriculturalDistributionNetwork.getDemandQuantity())));
            }else{
                //不包含 把key和需求数量添加
                agriculturalDistributionNetworkMap.
                        put(key,new BigDecimal(agriculturalDistributionNetwork.getDemandQuantity()));
            }

        });
        //去重统计各个部门需求数量（流程表）
        processTrackingList.forEach(processTracking -> {
            String key = processTracking.getMaterialCode() + "-" + reportPersonMap.get(processTracking.getApplicant());
            if (processTrackingMap.containsKey(key)) {
                processTrackingMap.put(key,processTrackingMap.get(key).add(new BigDecimal(processTracking.getDemandQuantity())));
            }else{
                processTrackingMap.put(key,new BigDecimal(processTracking.getDemandQuantity()));
            }
        });


        //两个表 相比
        processTrackingMap.forEach((k,v)->{
            String[] split = k.split("-");
            String person = getPerson(reportPersonMap, split[1], agriculturalDistributionNetworkList, split[0]);
            String dictLabels = DictUtils.getDictLabel(reportPersonMap.get(person), "report_department", "");
            String materialDescription = getMaterialDescription(split[0], person, agriculturalDistributionNetworkList);
            planSummaryList.add(new PlanSummary(person,dictLabels,split[0],materialDescription,v.toString(),
                    //配农网是否有这个key
                    agriculturalDistributionNetworkMap.containsKey(k)?
                            agriculturalDistributionNetworkMap.get(k).toString():null,
                    //需求数量是否为0  如果不为0 计算执行进度 如果为0则显示未上报
                    //如果有这个key并且不是null时，配农网的key / 流程跟踪表的v
                    agriculturalDistributionNetworkMap.containsKey(k)
                            &&
                            agriculturalDistributionNetworkMap.get(k)!=null?
                            agriculturalDistributionNetworkMap.get(k).compareTo(new BigDecimal(0))==0?
                                    "未上报需求":(agriculturalDistributionNetworkMap.get(k).
                                    divide(v,1,BigDecimal.ROUND_HALF_DOWN))+ "%":
                            "未上报需求"
            ));

        });

        return planSummaryList;

    }
        //申请人
    private String getPerson(Map<String,String> map,String department,List<AgriculturalDistributionNetwork> agriculturalDistributionNetworkList,String requiredMaterialCode){
        List<String> person = new ArrayList<>();
        AtomicReference<String> name = new AtomicReference<>("");
        map.forEach((k,v)->{
            if(v.equals(department)){
                person.add(k);
            }
        });
        agriculturalDistributionNetworkList.forEach(l->{
            if(l.getRequiredMaterialCode().equals(requiredMaterialCode)){
                name.set(l.getPlanSubmitter());
            }
        });
        return name.get();
    }
        //物料描述
    private String getMaterialDescription(String requiredMaterialCode,String name,List<AgriculturalDistributionNetwork> agriculturalDistributionNetworkList){
        AtomicReference<String> materialDescription = new AtomicReference<>("");
        agriculturalDistributionNetworkList.forEach(l->{
            if(requiredMaterialCode.equals(l.getRequiredMaterialCode())&&name.equals(l.getPlanSubmitter())){
                materialDescription.set(l.getMaterialDescription());
            }
        });
        return materialDescription
                .get();
    }

    /**
     * 查询数据库数据获取对应的部门和部门下对应的人
     * @return
     */
    private Map<String,String> getPerson(){
        Map<String,String> map = new HashMap<>();
        List<ReportPerson> departmentGroupByPerson = reportPersonMapper.findDepartmentGroupByPerson();
        departmentGroupByPerson.forEach(person->{
            map.put(person.getReportPerson(),person.getReportDepartment());
        });
        return map;
    }

}
