/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.sg.balancedlibrary.preferredMaterials.web;

import com.google.common.collect.Lists;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.utils.ImportUtil;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.entity.LiKuResourcePool;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.service.LiKuResourcePoolService;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.utils.LiKuUtils;
import com.jeeplus.modules.sg.balancedlibrary.materialQuota.entity.MaterialQuota;
import com.jeeplus.modules.sg.balancedlibrary.materialQuota.service.MaterialQuotaService;
import com.jeeplus.modules.sg.balancedlibrary.preferredMaterials.entity.PreferredMaterials;
import com.jeeplus.modules.sg.balancedlibrary.preferredMaterials.service.PreferredMaterialsService;
import org.apache.poi.ss.usermodel.Row;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.ConstraintViolationException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * 优选物料Controller
 * @author lgf
 * @version 2018-06-12
 */
@Controller
@RequestMapping(value = "${adminPath}/preferredMaterials")
public class PreferredMaterialsController extends BaseController {

	@Autowired
	private PreferredMaterialsService service;



	@ModelAttribute
	public PreferredMaterials get(@RequestParam(required=false) String id) {
		PreferredMaterials entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = service.get(id);
		}
		if (entity == null){
			entity = new PreferredMaterials();
		}
		return entity;
	}
	
	/**
	 * 优选物料列表页面
	 */
	@RequiresPermissions("sg:balancedlibrary:preferredMaterials:list")
	@RequestMapping(value = "list")
	public String list(PreferredMaterials entity, Model model) {
		model.addAttribute("entity", entity);
		return "modules/sg/balancedlibrary/preferredMaterials/preferredMaterialsList";
	}
	
		/**
	 * 优选物料列表数据
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:preferredMaterials:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(PreferredMaterials entity, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<PreferredMaterials> page = service.findPage(new Page<PreferredMaterials>(request, response), entity);
		return getBootstrapData(page);
	}


	/**
	 * 批量删除优选物料
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:preferredMaterials:del")
	@RequestMapping(value = "deleteAll")
	public AjaxJson deleteAll(String ids) {
		AjaxJson j = new AjaxJson();
		String idArr[] =ids.split(",");
		List<String> idList = Arrays.asList(idArr);
		service.deleteList(idList);
		j.setMsg("删除优选物料成功");
		return j;
	}
	
	/**
	 * 导出excel文件
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:preferredMaterials:export")
    @RequestMapping(value = "export")
    public AjaxJson exportFile(PreferredMaterials entity, HttpServletRequest request, HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "优选物料表"+DateUtils.getDate("yyyyMMddHHmmss")+".xlsx";
            Page<PreferredMaterials> page = service.findPage(new Page<PreferredMaterials>(request, response, -1), entity);
    		new ExportExcel("", PreferredMaterials.class).setDataList(page.getList()).write(response, fileName).dispose();
    		j.setSuccess(true);
    		j.setMsg("导出成功！");
    		return j;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导出优选物料表失败！失败信息："+e.getMessage());
		}
			return j;
    }

	/**
	 * 优选物料-导入Excel数据
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:preferredMaterials:import")
    @RequestMapping(value = "import")
   	public AjaxJson importFile(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
		AjaxJson j = new AjaxJson();
		try {
			ImportUtil ei = new ImportUtil(file,0,0);
			List<PreferredMaterials> list = ei.getDataList(PreferredMaterials.class);
			if (list.size() > 0) {
				//优选物资每次重新导入数据，将原有数据清空
				service.fullReplace(list);
				j.setMsg("已成功导入 " + list.size() + " 条优选物料记录");
			}
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入优选物料失败！失败信息："+e.getMessage());
		}
		return j;
    }



	/**
	 * 下载导入优选物料数据模板
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:preferredMaterials:import")
    @RequestMapping(value = "import/template")
     public AjaxJson importFileTemplate(HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "优选物料数据导入模板.xlsx";
    		List<PreferredMaterials> list = Lists.newArrayList();
    		new ExportExcel("", PreferredMaterials.class, 1).setDataList(list).write(response, fileName).dispose();
    		return null;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg( "导入模板下载失败！失败信息："+e.getMessage());
		}
		return j;
    }

}