/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.sg.balancedlibrary.reportPerson.web;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Date;

import com.jeeplus.modules.sg.balancedlibrary.reportPerson.entity.ReportPerson;
import com.jeeplus.modules.sg.balancedlibrary.reportPerson.service.ReportPersonService;
import com.jeeplus.modules.sys.entity.User;

import com.google.common.collect.Lists;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.common.utils.excel.ImportExcel;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.entity.LiKuResourcePool;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.service.LiKuResourcePoolService;
import com.jeeplus.modules.sg.balancedlibrary.replaceMaterial.entity.ReplaceMaterial;
import com.jeeplus.modules.sg.balancedlibrary.replaceMaterial.service.ReplaceMaterialService;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.DataFormat;
import org.apache.poi.ss.usermodel.Row;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.ConstraintViolationException;
import java.util.List;
import java.util.Map;

/**
 * 提报人Controller
 * @author enford
 * @version 1.0
 */
@Controller
@RequestMapping(value = "${adminPath}/reportPerson")
public class ReportPersonController extends BaseController {

	@Autowired
	private ReportPersonService service;
	
	@ModelAttribute
	public ReportPerson get(@RequestParam(required=false) String id) {
		ReportPerson entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = service.get(id);
		}
		if (entity == null){
			entity = new ReportPerson();
		}
		return entity;
	}
	
	/**
	 * 提报人列表页面
	 */
	@RequiresPermissions("sg:balancedlibrary:reportPerson:list")
	@RequestMapping(value = "list")
	public String list(ReportPerson entity, Model model) {
		model.addAttribute("entity", entity);
		return "modules/sg/balancedlibrary/reportPerson/reportPersonList";
	}
	
	/**
	 * 提报人列表数据
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:reportPerson:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(ReportPerson entity, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<ReportPerson> page = service.findPage(new Page<ReportPerson>(request, response), entity);
		return getBootstrapData(page);
	}

	/**
	 * 查看，增加，编辑提报人表单页面
	 */
	@RequiresPermissions(value={"sg:balancedlibrary:reportPerson:view","sg:balancedlibrary:reportPerson:add","sg:balancedlibrary:reportPerson:edit"},logical=Logical.OR)
	@RequestMapping(value = "form")
	public String form(ReportPerson entity, Model model) {
		model.addAttribute("entity", entity);
		return "modules/sg/balancedlibrary/reportPerson/reportPersonForm";
	}

	/**
	 * 保存提报人
	 */
	@ResponseBody
	@RequiresPermissions(value={"sg:balancedlibrary:reportPerson:add","sg:balancedlibrary:reportPerson:edit"},logical=Logical.OR)
	@RequestMapping(value = "save")
	public AjaxJson save(ReportPerson entity, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(entity);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		service.save(entity);
		j.setSuccess(true);
		j.setMsg("保存提报人成功");
		return j;
	}
	
	/**
	 * 删除提报人
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:reportPerson:del")
	@RequestMapping(value = "delete")
	public AjaxJson delete(ReportPerson entity) {
		AjaxJson j = new AjaxJson();
		service.delete(entity);
		j.setMsg("删除提报人成功");
		return j;
	}
	
	/**
	 * 批量删除提报人
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:reportPerson:del")
	@RequestMapping(value = "deleteAll")
	public AjaxJson deleteAll(String ids) {
		AjaxJson j = new AjaxJson();
		String idArray[] =ids.split(",");
		for(String id : idArray){
			service.delete(service.get(id));
		}
		j.setMsg("删除提报人成功");
		return j;
	}
	


}