/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.sg.balancedlibrary.standardMaterials.web;

import com.google.common.collect.Lists;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.utils.ImportUtil;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.entity.LiKuResourcePool;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.service.LiKuResourcePoolService;
import com.jeeplus.modules.sg.balancedlibrary.liKuResourcePool.utils.LiKuUtils;
import com.jeeplus.modules.sg.balancedlibrary.standardMaterials.entity.StandardMaterials;
import com.jeeplus.modules.sg.balancedlibrary.standardMaterials.service.StandardMaterialsService;
import org.apache.poi.ss.usermodel.Row;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.ConstraintViolationException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * 标准物资Controller
 * @author lgf
 * @version 2018-06-12
 */
@Controller
@RequestMapping(value = "${adminPath}/standardMaterials")
public class StandardMaterialsController extends BaseController {

	@Autowired
	private StandardMaterialsService service;



	@ModelAttribute
	public StandardMaterials get(@RequestParam(required=false) String id) {
		StandardMaterials entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = service.get(id);
		}
		if (entity == null){
			entity = new StandardMaterials();
		}
		return entity;
	}
	
	/**
	 * 标准物资列表页面
	 */
	@RequiresPermissions("sg:balancedlibrary:standardMaterials:list")
	@RequestMapping(value = "list")
	public String list(StandardMaterials entity, Model model) {
		model.addAttribute("entity", entity);
		return "modules/sg/balancedlibrary/standardMaterials/standardMaterialsList";
	}
	
	/**
	 * 标准物资列表数据
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:standardMaterials:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(StandardMaterials entity, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<StandardMaterials> page = service.findPage(new Page<StandardMaterials>(request, response), entity);
		return getBootstrapData(page);
	}


	
	/**
	 * 批量删除标准物资
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:standardMaterials:del")
	@RequestMapping(value = "deleteAll")
	public AjaxJson deleteAll(String ids) {
		AjaxJson j = new AjaxJson();
		String idArr[] =ids.split(",");
		List<String> idList = Arrays.asList(idArr);
		service.deleteList(idList);
		j.setMsg("删除标准物资成功");
		return j;
	}
	
	/**
	 * 导出excel文件
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:standardMaterials:export")
    @RequestMapping(value = "export")
    public AjaxJson exportFile(StandardMaterials entity, HttpServletRequest request, HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "标准物资情况表"+DateUtils.getDate("yyyyMMddHHmmss")+".xlsx";
            Page<StandardMaterials> page = service.findPage(new Page<StandardMaterials>(request, response, -1), entity);
    		new ExportExcel("", StandardMaterials.class).setDataList(page.getList()).write(response, fileName).dispose();
    		j.setSuccess(true);
    		j.setMsg("导出成功！");
    		return j;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导出标准物资表失败！失败信息："+e.getMessage());
		}
			return j;
    }

	/**
	 * 标准物资-导入Excel数据
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:standardMaterials:import")
    @RequestMapping(value = "import")
   	public AjaxJson importFile(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
		AjaxJson j = new AjaxJson();
		try {
			ImportUtil ei = new ImportUtil(file,0,0);
			List<StandardMaterials> list = ei.getDataList(StandardMaterials.class);
			for(StandardMaterials material:list){
				if("非国网采购标准物料".equals(material.getPurchaseStandardId())){
					material.setPurchaseStandardId("非标物料");
				}
			}
			if (list.size() > 0) {
				//标准物资每次重新导入数据，将原有数据清空
				service.fullReplace(list);
				j.setMsg("已成功导入 " + list.size() + " 条标准物资记录");
			}
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入标准物资失败！失败信息："+e.getMessage());
		}
		return j;
    }



	/**
	 * 下载导入标准物资数据模板
	 */
	@ResponseBody
	@RequiresPermissions("sg:balancedlibrary:standardMaterials:import")
    @RequestMapping(value = "import/template")
     public AjaxJson importFileTemplate(HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "标准物资数据导入模板.xlsx";
    		List<StandardMaterials> list = Lists.newArrayList();
    		new ExportExcel("", StandardMaterials.class, 1).setDataList(list).write(response, fileName).dispose();
    		return null;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg( "导入模板下载失败！失败信息："+e.getMessage());
		}
		return j;
    }

}