package com.jeeplus.modules.sg.budgetSpectaculars.service;

import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.sg.budgetSpectaculars.entity.ProjectScheduleStatInfo;
import com.jeeplus.modules.sg.budgetSpectaculars.mapper.ProjectScheduleStatMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 项目进度统计Service
 * @author: 徐滕
 * @create: 2021-11-25 09:00
 **/
@Service
@Transactional(readOnly = true)
public class ProjectScheduleStatService extends CrudService<ProjectScheduleStatMapper, ProjectScheduleStatInfo> {

    @Autowired
    private ProjectScheduleStatMapper mapper;

    public Page<ProjectScheduleStatInfo> findPage(Page<ProjectScheduleStatInfo> page, ProjectScheduleStatInfo entity) {
        Page<ProjectScheduleStatInfo> page1 = super.findPage(page, entity);
        List<ProjectScheduleStatInfo> list = page1.getList();
        for (ProjectScheduleStatInfo info: list) {
            List<ProjectScheduleStatInfo> listBySecondLevelUnitAndProjectType = mapper.getListBySecondLevelUnitAndProjectType(info);
            disposeData(info,listBySecondLevelUnitAndProjectType);
        }
        return page1;
    }

    /**
     * 数据处理
     * @param list
     */
    public void disposeData(ProjectScheduleStatInfo scheduleStatInfo,List<ProjectScheduleStatInfo> list){
        Integer notStartWorkCount = 0; //项目未开工数量
        Integer startWorkCount = 0; //开工数量
        Integer completionCount = 0;    //竣工数量
        Integer calculationForReviewCount = 0;  //结算送审数量
        Integer calculationExamineCount = 0;    //结算审定数量
        Integer whichMaterialStoresReturnedCount = 0;   //发起甲供材领退料数量
        Integer rejectedMaterialFinishCount = 0;    //领退料完成数量
        Integer completedActualBudgetCount = 0; //提报竣工决算数量
        Integer actualBudgetSubmittalsCount = 0;    //决算送审数量
        Integer actualBudgetauditReportCount = 0;   //出具决算审计报告数量
        Integer projectCloseCount = 0;  //项目关闭数量

        //对数据进行遍历进行展示处理
        for (ProjectScheduleStatInfo info: list) {
            String dataQualityInspection = "未通过";
            //实际开工日期<实际竣工日期<结算送审日期<结算审定日期<发起甲供材领退料日期<领退料是否完成（是）<提报竣工决算日期<决算送审日期<出具决算审计报告日期<项目是否关闭（是）
            //项目开工、项目竣工、结算送审、结算审定、发起甲供材领退料、领退料完成、提报竣工决算、决算送审、出具决算审计报告、项目关闭。

            if(StringUtils.isNotBlank(info.getIfProjectClose()) && "是".equals(info.getIfProjectClose())){//项目关闭状态
                projectCloseCount ++;
            }else if(StringUtils.isNotBlank(info.getActualBudgetauditReportTime())){//项目出具决算审计报告日期
                actualBudgetauditReportCount ++;

            }else if(StringUtils.isNotBlank(info.getActualBudgetSubmittalsTime())){//项目发决算送审日期
                actualBudgetSubmittalsCount ++;

            }else if(StringUtils.isNotBlank(info.getCompletedActualBudgetTime())){//项目提报竣工决算日期
                completedActualBudgetCount ++;

            }else if(StringUtils.isNotBlank(info.getIfGetRejectedMaterialFinish()) && "是".equals(info.getIfGetRejectedMaterialFinish())){//项目领退料完成状态
                rejectedMaterialFinishCount ++;

            } else if(StringUtils.isNotBlank(info.getWhichMaterialStoresReturnedTime())){//项目发起甲供材领退料日期
                whichMaterialStoresReturnedCount ++;

            }else if(StringUtils.isNotBlank(info.getCalculationExamineTime())){//项目结算审定日期
                calculationExamineCount ++;

            } else if(StringUtils.isNotBlank(info.getCalculationForReviewTime())){//项目结算送审日期
                calculationForReviewCount ++;

            }else if(StringUtils.isNotBlank(info.getPracticalcompletionDate())){//项目竣工日期
                completionCount ++;

            } else if(StringUtils.isNotBlank(info.getFirstAcquisitionTime())) { //首次领料日期
                startWorkCount ++ ;

            }else{
                notStartWorkCount ++;
            }
        }

        scheduleStatInfo.setNotStartWorkCount(notStartWorkCount);
        scheduleStatInfo.setStartWorkCount(startWorkCount);
        scheduleStatInfo.setCompletionCount(completionCount);
        scheduleStatInfo.setCalculationForReviewCount(calculationForReviewCount);
        scheduleStatInfo.setCalculationExamineCount(calculationExamineCount);
        scheduleStatInfo.setWhichMaterialStoresReturnedCount(whichMaterialStoresReturnedCount);
        scheduleStatInfo.setRejectedMaterialFinishCount(rejectedMaterialFinishCount);
        scheduleStatInfo.setCompletedActualBudgetCount(completedActualBudgetCount);
        scheduleStatInfo.setActualBudgetSubmittalsCount(actualBudgetSubmittalsCount);
        scheduleStatInfo.setActualBudgetauditReportCount(actualBudgetauditReportCount);
        scheduleStatInfo.setProjectCloseCount(projectCloseCount);
        scheduleStatInfo.setTotalCount(notStartWorkCount + startWorkCount + completionCount + calculationForReviewCount +
                calculationExamineCount + whichMaterialStoresReturnedCount + rejectedMaterialFinishCount + completedActualBudgetCount +
                actualBudgetSubmittalsCount + actualBudgetauditReportCount + projectCloseCount);
    }
}
