/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.sg.classification.uti;

import java.io.*;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.text.NumberFormat;
import java.text.SimpleDateFormat;
import java.util.Collections;
import java.util.Comparator;
import java.util.Date;
import java.util.List;

import com.jeeplus.common.utils.Encodes;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.multipart.MultipartFile;

import com.google.common.collect.Lists;
import com.jeeplus.common.utils.Reflections;
import com.jeeplus.common.utils.excel.annotation.ExcelField;
import com.jeeplus.modules.sys.entity.Area;
import com.jeeplus.modules.sys.entity.Office;
import com.jeeplus.modules.sys.entity.User;
import com.jeeplus.modules.sys.utils.DictUtils;
import com.jeeplus.modules.sys.utils.UserUtils;

import javax.servlet.http.HttpServletResponse;

/**
 * 导入Excel文件（支持“XLS”和“XLSX”格式）
 * @author jeeplus
 * @version 2016-03-10
 */
public class ImportExcel {

	private static Logger log = LoggerFactory.getLogger(ImportExcel.class);

	/**
	 * 工作薄对象
	 */
	private Workbook wb;

	/**
	 * 工作表对象
	 */
	private Sheet sheet;

	/**
	 * 标题行号
	 */
	private int headerNum;




	public ImportExcel(MultipartFile multipartFile, int headerNum, int sheetIndex)
			throws InvalidFormatException, IOException {
		this(multipartFile.getOriginalFilename(), multipartFile.getInputStream(), headerNum, sheetIndex);
	}


	/**
	 * 构造函数
	 * @param headerNum 标题行号，数据行号=标题行号+1
	 * @param sheetIndex 工作表编号
	 * @throws InvalidFormatException
	 * @throws IOException
	 */
	public ImportExcel(String fileName, InputStream is, int headerNum, int sheetIndex)
			throws InvalidFormatException, IOException {
		if (StringUtils.isBlank(fileName)){
			throw new RuntimeException("导入文档为空!");
		}else if(fileName.toLowerCase().endsWith("xls")){
			this.wb = new HSSFWorkbook(is);
		}else if(fileName.toLowerCase().endsWith("xlsx")){
			this.wb = new XSSFWorkbook(is);
		}else{
			throw new RuntimeException("文档格式不正确!");
		}
		if (this.wb.getNumberOfSheets()<sheetIndex){
			throw new RuntimeException("文档中没有工作表!");
		}
		this.sheet = this.wb.getSheetAt(sheetIndex);
		this.headerNum = headerNum;
		log.debug("Initialize success.");
	}


	/**
	 * 获取行对象
	 * @param rownum
	 * @return
	 */
	public Row getRow(int rownum){
		return this.sheet.getRow(rownum);
	}

	/**
	 * 获取数据行号
	 * @return
	 */
	public int getDataRowNum(){
		return headerNum+1;
	}

	/**
	 * 获取最后一个数据行号
	 * @return
	 */
	public int getLastDataRowNum(){
		return this.sheet.getLastRowNum();
	}

	/**
	 * 获取最后一个列号
	 * @return
	 */
	public int getLastCellNum(){
		return this.getRow(headerNum).getLastCellNum();
	}


	public void classify() throws Exception {
		int firstLine = headerNum;
		int lastLine = this.sheet.getLastRowNum();
		if(lastLine<=firstLine)
			throw new Exception("no data!");
		for(int i= firstLine;i<=lastLine;i++){
			Row row = sheet.getRow(i);
			String reason = getStringValue(row,30);
			Double num1 = getDoubleValue(row,47);//变压器
			Double num2 = getDoubleValue(row,39);//环网柜
			Double num3 = getDoubleValue(row,51);//低压分支箱
			Double num4 = getDoubleValue(row,62);//高压分支箱
			Double num5 = getDoubleValue(row,45);//箱变
			Double num6 = getDoubleValue(row,37);//电缆
			Double num7 = getDoubleValue(row,50);//低压电缆
			String classfilation = "";
			if((reason.contains("移位")||reason.contains("迁移")||reason.contains("变压器")||reason.contains("配变"))&&
					(num1==null||num1==0)){
				classfilation = "配变移位:将变压器进行移位";
			}else if((reason.contains("移位")||reason.contains("迁移")||reason.contains("变压器")||reason.contains("配变"))&&
					(num1 !=null&&num1>0)){
				classfilation = "配变移位改造:将配变进行移位改造新建";
			}else if((reason.contains("新增")||reason.contains("新设")||reason.contains("新上"))&&
					(num2 !=null&&num2>0)){
				classfilation = "环网柜新建：新设环网柜，并对基础进行改造";
			}else if((reason.contains("更换"))&&
					(num2 !=null&&num2>0)){
				classfilation = "环网柜改造:更换环网柜，同时进行自动化改造";
			}else if((reason.contains("更换或维修")&&reason.contains("低压分支箱"))&&
					(num3 !=null&&num3>0)){
				classfilation = "低压分支箱:更换低压分支箱";
			}else if((reason.contains("更换或维修")&&reason.contains("高压分支箱"))&&
					(num4 !=null&&num4>0)){
				classfilation = "分支箱更换:更换高压分支箱";
			}else if((reason.contains("分支箱改"))&&
					(num2 !=null&&num2>0)){
				classfilation = "分支箱换环网柜:分支箱换环网柜";
			}else if(reason.contains("更换")&&
					(num5 !=null&&num5>0)){
				classfilation = "箱变更换:更换箱变";
			}else if((reason.contains("下地"))&&
					(num6 !=null&&num6>0)){
				classfilation = "电缆项目:杆线进行下地改造";
			}else if((reason.contains("电缆老"))&&
					((num6 !=null&&num6>0)||(num7 !=null&&num7>0))){
				classfilation = "电缆项目:电缆严重老化，线经过小，将原电缆更换";
			}else if(reason.contains("更换电缆")){
				classfilation = "电缆项目:环网柜电缆维修";
			}else if(reason.contains("更换开关")||reason.contains("开关改造")||reason.contains("改造开关")){
				classfilation = "线路开关维修:对开关进行自动化改造，改造为集中型、三遥自动化装置，通信方式优先光纤，不满足条件时可采用无线专网";
			}else if(reason.contains("新上开关")||reason.contains("新设开关")||reason.contains("增加开关")){
				classfilation = "用户分界开关:用户开关加装为智能分界开关，二遥，接入调度主站。";
			}else if(reason.contains("裸线")||reason.contains("裸导线")){
				classfilation = "杆线项目:拆除裸线，新设绝缘线，更换杆塔，提高该段线路运行安全";
			}else if(reason.contains("线树")||reason.contains("树线")){
				classfilation = "杆线项目:更换原绝缘线，更换杆塔，项目实施后，该段架空线路通道位置合理，运行巡视、抢修便利。";
			}else if(reason.contains("改接")){
				classfilation = "杆线项目:新建联络，拆除现有联络";
			}else if((reason.contains("开关站")&&reason.contains("分支箱"))||(reason.contains("电房")&&reason.contains("分支箱"))){
				classfilation = "开关站改造:开闭所内新设高压分支箱，拆除不利用设备";
			}else if(reason.contains("FA")||reason.contains("DTU")||reason.contains("二遥")||reason.contains("三遥")){
				classfilation = "自动化改造";
			}
			Cell cell = row.createCell(1);
			cell.setCellValue(classfilation);
		}

	}

	public String getStringValue(Row row,int column) throws Exception {
		Cell cell = row.getCell(column);
		if(cell !=null){
			return cell.getStringCellValue();
		}else{
			int line = row.getRowNum()+1;
			throw new Exception("找不到单元格第 "+line+" 行，第 "+(column+1)+" 列！");
		}
	}

	public Double getDoubleValue(Row row,int column) throws Exception {
		Cell cell = row.getCell(column);
		if(cell !=null){
			if (cell.getCellType() == Cell.CELL_TYPE_NUMERIC) {
				return cell.getNumericCellValue();
			}else if(cell.getCellType() == Cell.CELL_TYPE_STRING){
				return Double.parseDouble(cell.getStringCellValue());
			}else{
				String temp = cell.getStringCellValue();
				if(StringUtils.isBlank(temp)){
					return 0.0;
				}else{
					int line = row.getRowNum()+1;
					throw new Exception("单元格格式错误第 "+line+" 行，第 "+(column+1)+" 列！");
				}
			}
		}else{
			int line = row.getRowNum()+1;
			throw new Exception("找不到单元格第 "+line+" 行，第 "+(column+1)+" 列！");
		}

	}


	public ImportExcel writeFile(String name) throws FileNotFoundException, IOException{
		File file = new File(name);
		FileOutputStream os = new FileOutputStream(file);
		this.write(os);
		return this;
	}
	public ImportExcel write(OutputStream os) throws IOException{
		wb.write(os);
		os.close();
		return this;
	}
	/**
	 * 输出到客户端
	 * @param fileName 输出文件名
	 */
	public ImportExcel write(HttpServletResponse response, String fileName) throws IOException{
		response.reset();
		response.setContentType("application/octet-stream; charset=utf-8");
		response.setHeader("Content-Disposition", "attachment; filename="+Encodes.urlEncode(fileName));
		write(response.getOutputStream());
		return this;
	}

	public ImportExcel(InputStream is){
		try {
			wb = new XSSFWorkbook(is);
			sheet = wb.getSheetAt(0);
		} catch (IOException e) {
			e.printStackTrace();
		}finally {
			if(is!=null){
				try {
					is.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
	}

}
