package com.jeeplus.modules.sg.financial.erpcredit.util;

import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.modules.filing.basicInformation.entity.BasicInformation;
import com.jeeplus.modules.sg.financial.erpcredit.entity.*;
import com.jeeplus.modules.sg.financial.settlement.entity.MaintainData;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFFont;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

/**
 * 写入表格中模板
 */
public class ExportUtil {

    /**
     * 封面写入数据
     * @param sheet
     * @param erpCredits
     * @param maintainDataList
     */
    public static void getSheetCover(Sheet sheet,List<ErpCredit> erpCredits,List<MaintainData> maintainDataList){
        if(sheet != null){

            ErpCredit credit = erpCredits.get(0);
            MaintainData maintainData = maintainDataList.get(0);
            String profitCenter = credit.getProfitCenter();
            String projectDefinitionCode = credit.getItemId();


            XSSFRow row1 = (XSSFRow) sheet.getRow(2);
            XSSFCell cell1 = getViewCell(row1,0);//公司名称

            XSSFRow row2 = (XSSFRow) sheet.getRow(6);
            XSSFCell cell2 = getViewCell(row2,0);//文件名

            XSSFRow row3 = (XSSFRow) sheet.getRow(9);
            XSSFCell cellx = row3.getCell(0);
            XSSFCell cell3 = getViewCell(row3,6);;//项目名称

            XSSFRow row4 = (XSSFRow) sheet.getRow(16);
            XSSFCell cell4 = getViewCell(row4,0);;//报送日期

            XSSFRow row5 = (XSSFRow) sheet.getRow(21);
            XSSFCell cell5 = getViewCell(row5,0);;//财务负责人及编制人

            if("L010010501".equals(profitCenter)){
                cell1.setCellValue("国网江苏省电力有限公司常州供电分公司");
                cell5.setCellValue("财务负责人：贺雪霞                       编制人：  王勇");

                String proName = "20"+projectDefinitionCode.substring(6,8)+"年国网江苏省电力有限公司常州供电分公司配网"
                        +erpCredits.size()+"个项目";
                cell3.setCellValue(proName);
            }else{

            }
            String fileName = "20"+projectDefinitionCode.substring(6,8)+"年配网改造工程项目竣工决算报告";
            cell2.setCellValue(fileName);
            Calendar cal = Calendar.getInstance();
            String submitDate = "报送日期："+cal.get(Calendar.YEAR)+"年"+(cal.get(Calendar.MINUTE)+1)+"月";
            cell4.setCellValue(submitDate);

        }
    }

    /**
     * 概述表写入数据
     * @param sheet
     * @param erpCredits
     * @param maintainDataList
     */
    public static void getSheetOverView(Sheet sheet, List<ErpCredit> erpCredits, List<MaintainData> maintainDataList){
        if (sheet!=null) {
            GeneralSituation generalSituation = ExportUtilCalculate.getFeneraSituation(erpCredits, maintainDataList);
            XSSFRow row = (XSSFRow) sheet.getRow(6);
            XSSFCell cell = row.getCell(6);
            cell.setCellValue(generalSituation.getOrganDataNumber());//日期，批文号

            row = (XSSFRow) sheet.getRow(2);
            cell = row.getCell(0);//编制单位
            cell.setCellValue(getCompany(erpCredits));
            cell = getViewCell(row, 6);//编制日期
            cell.setCellValue(getCurrentDate());

            row = (XSSFRow) sheet.getRow(3);
            cell = row.getCell(1);//工程名称
            cell.setCellValue(generalSituation.getProjectName());
            cell = row.getCell(6);//设计单位
            cell.setCellValue(generalSituation.getDesignUnit());

            row = (XSSFRow) sheet.getRow(5);
            cell = row.getCell(6);//施工单位
            cell.setCellValue(generalSituation.getBuildUnit());

            row = (XSSFRow) sheet.getRow(9);
            cell = row.getCell(2);
//            cell.setCellValue(generalSituation.getLineLength());
//            cell.setCellValue(Double.parseDouble(generalSituation.getLineLength()));
            setCellDoubleValue(cell, generalSituation.getLineLength());
            cell = row.getCell(7);
            cell.setCellValue(generalSituation.getCommencementDate());

            row = (XSSFRow) sheet.getRow(10);
            cell = row.getCell(2);
//            cell.setCellValue(Double.parseDouble(generalSituation.getTenKvLength()));
            setCellDoubleValue(cell, generalSituation.getTenKvLength());
            cell = row.getCell(7);
            cell.setCellValue(generalSituation.getCompletionDate());

            row = (XSSFRow) sheet.getRow(11);
            cell = row.getCell(2);
//            cell.setCellValue(Double.parseDouble(generalSituation.getFourKvLength()));
            setCellDoubleValue(cell, generalSituation.getFourKvLength());

            row = (XSSFRow) sheet.getRow(12);
            cell = row.getCell(7);
//            cell.setCellValue(Double.parseDouble(generalSituation.getInvestmentBudget()));
            setCellDoubleValue(cell, generalSituation.getInvestmentBudget());

            row = (XSSFRow) sheet.getRow(13);
            cell = row.getCell(7);
//            cell.setCellValue(Double.parseDouble(generalSituation.getActualInvestment()));//实际投资
            setCellDoubleValue(cell, generalSituation.getActualInvestment());

            row = (XSSFRow) sheet.getRow(14);
            cell = row.getCell(7);
//            cell.setCellValue(Double.parseDouble(generalSituation.getTransferAssets()));
            setCellDoubleValue(cell, generalSituation.getTransferAssets());

            row = (XSSFRow) sheet.getRow(16);
            cell = row.getCell(7);
//            cell.setCellValue(Double.parseDouble(generalSituation.getHasItsOwn()));
            setCellDoubleValue(cell, generalSituation.getHasItsOwn());
        }
    }

    /**
     * 一览表写入数据
     * @param sheet
     * @param erpCredits
     * @param maintainDataList
     * @param workbook
     */
    public static void getSheetView(Sheet sheet,List<ErpCredit> erpCredits,List<MaintainData> maintainDataList,Workbook workbook){
        if (sheet!=null){
            CellStyle cellStyleFont = getCellStyleFont(workbook);
            CellStyle cellStyle = getCellStyle(workbook);
            Schedule schedule = null;
            XSSFRow row = (XSSFRow) sheet.createRow(2);
            XSSFCell cell = getViewCell(row,0);//编制单位
            cell.setCellValue(getCompany(erpCredits));
            cell = getViewCell(row,6);//编制日期
            cell.setCellValue(getCurrentDate());
            List<Schedule> scheduleList = ExportUtilCalculate.getScheduleList(erpCredits, maintainDataList);
            for (int i = 0; i <scheduleList.size(); i++) {
                int total = scheduleList.size()-1;//总数据条数
                schedule = scheduleList.get(i);
                row=(XSSFRow)sheet.createRow(i+6);
                cell = getViewCell(row,0,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(i+1);//序号


                cell = getViewCell(row,1,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(schedule.getItemId());//项目定义编码

                cell = getViewCell(row,2,i,total,cellStyle,cellStyleFont);
                cell.setCellValue("");//项目编码

                cell = getViewCell(row,3,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(schedule.getItemName());//工程名称

                cell = getViewCell(row,4,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(Double.parseDouble(schedule.getBudgetBuildProject()));//建筑工程预算
                setCellDoubleValue(cell, schedule.getBudgetBuildProject());

                cell = getViewCell(row,5,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(Double.parseDouble(schedule.getBudgetInstallProject()));//安装工程预算
                setCellDoubleValue(cell, schedule.getBudgetInstallProject());

                cell = getViewCell(row,6,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(Double.parseDouble(schedule.getBudgetEquipmentValue()));//设备价值预算
                setCellDoubleValue(cell, schedule.getBudgetEquipmentValue());

                cell = getViewCell(row,7,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(Double.parseDouble(schedule.getBudgetOtherFee()));//其他费用预算
                setCellDoubleValue(cell, schedule.getBudgetOtherFee());

                cell = getViewCell(row,8,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(Double.parseDouble(schedule.getBudgetTotalFee()));//合计预算
                setCellDoubleValue(cell, schedule.getBudgetTotalFee());

                cell = getViewCell(row,9,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(Double.parseDouble(schedule.getActualBuildProject()));//建筑工程实际
                setCellDoubleValue(cell, schedule.getActualBuildProject());

                cell = getViewCell(row,10,i,total,cellStyle,cellStyleFont);
                String actualIntallProject = schedule.getActualIntallProject();
                String actualEquipmentValue = schedule.getActualEquipmentValue();
                if (null == actualIntallProject || "".equals(actualIntallProject)) {
                    actualIntallProject = "0.0";
                }
                if (null == actualEquipmentValue || "".equals(actualEquipmentValue)) {
                    actualEquipmentValue = "0.0";
                }
                BigDecimal all = new BigDecimal(actualIntallProject);
                BigDecimal mul = new BigDecimal(actualEquipmentValue);
                BigDecimal bigDecimal = all.subtract(mul);
                cell.setCellValue(bigDecimal.doubleValue());//安装工程实际

                cell = getViewCell(row,11,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(Double.parseDouble(schedule.getActualEquipmentValue()));//设备价值实际
                setCellDoubleValue(cell, schedule.getActualEquipmentValue());

                cell = getViewCell(row,12,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(Double.parseDouble(schedule.getActualOtherFee()));//其他费用实际
                setCellDoubleValue(cell, schedule.getActualOtherFee());

                cell = getViewCell(row,13,i,total,cellStyle,cellStyleFont);
                String actualTotalFee = schedule.getActualTotalFee();
                if (null == actualTotalFee || "".equals(actualTotalFee)) {
                    actualTotalFee = "0.0";
                }
                BigDecimal actual = new BigDecimal(actualTotalFee);
                BigDecimal subtract = actual.subtract(mul);
                cell.setCellValue(subtract.doubleValue());//合计实际


                cell = getViewCell(row,14,i,total,cellStyle,cellStyleFont);
                String listDeduction = schedule.getListDeduction();//抵扣增值税
//                cell.setCellValue(Double.parseDouble(listDeduction));
                setCellDoubleValue(cell, listDeduction);

                BigDecimal allDecimal = new BigDecimal("0.0");
                if (null != listDeduction && !"".equals(listDeduction)) {
                    allDecimal = new BigDecimal(listDeduction);
                }
                BigDecimal add = allDecimal.add(subtract);

                cell = getViewCell(row,15,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(add.doubleValue());//实际含税投资合计


                cell = getViewCell(row,16,i,total,cellStyle,cellStyleFont);
                String addSubtractionLines = schedule.getAddSubtractionLines();
                if (null == addSubtractionLines || "".equals(addSubtractionLines)) {
                    addSubtractionLines = "0.0";
                }
                BigDecimal addSub = new BigDecimal(addSubtractionLines);
                BigDecimal decimal = addSub.subtract(mul);
                cell.setCellValue(decimal.doubleValue()); //增减额

                cell = getViewCell(row,17,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(Double.parseDouble(schedule.getAddSubtractionRate()));//增减率
                setCellDoubleValue(cell, schedule.getAddSubtractionRate());
            }
        }

    }

    /**
     * 设置单元格double值
     * @param cell
     * @param value
     */
    public static void setCellDoubleValue(XSSFCell cell,String value){
        if(StringUtils.isNotBlank(value)){
            cell.setCellValue(Double.parseDouble(value));
        }
    }

    /**
     * 一览表创建cell单元格并设置格式
     * @param row
     * @param total
     * @param cellStyle
     * @param cellStyleFont
     * @return
     */
    public static XSSFCell getViewCell(XSSFRow row,int colIndex,int rowIndex,Integer total,CellStyle cellStyle,CellStyle cellStyleFont){
        XSSFCell cell = row.getCell(colIndex);
        if (cell == null){
            cell = row.createCell(colIndex);
        }
        if(total != null){
            if (rowIndex==total){
                cell.setCellStyle(cellStyleFont);
            }else{
                cell.setCellStyle(cellStyle);
            }
        }

        return cell;
    }

    /**
     * 获取单元格
     * @param row
     * @param colIndex
     * @return
     */
    public static XSSFCell getViewCell(XSSFRow row,int colIndex){
        XSSFCell cell = row.getCell(colIndex);
        if (cell == null){
            cell = row.createCell(colIndex);
        }
        return cell;
    }

    //读取得到其他费用表
    public static void getSheetOtherFee(Sheet sheet,List<ErpCredit> erpCredits,List<MaintainData> maintainDataList){
       if (null!=sheet){
           XSSFRow row = (XSSFRow) sheet.getRow(0);
           XSSFCell cell = row.getCell(3);
           ScheduleOther scheduleOtherAct = ExportUtilCalculate.getScheduleOfOtherExpenses(erpCredits);
           ScheduleOther scheduleOtherBud = ExportUtilCalculate.getScheduleOfOtherExpensesReg(maintainDataList);
           List<String> listAct = new ArrayList<String>();
           List<String> listBud = new ArrayList<String>();
           List<String> listActual = getListSchOther(listAct, scheduleOtherAct);
           List<String> listBudget = getListSchOther(listBud,scheduleOtherBud);
           for (int i = 0; i < listActual.size(); i++) {
               row = (XSSFRow) sheet.getRow((int)i+6);
               cell=row.getCell(3);
               cell.setCellValue((String)listActual.get(i));
           }
           for (int i = 0; i < listBudget.size(); i++) {
               row = (XSSFRow) sheet.getRow((int)i+6);
               cell=row.getCell(2);
               cell.setCellValue((String)listBudget.get(i));
           }
       }
   }

    /**
     * 其他费用表03  写入数据
     * @param sheet
     * @param erpCredits
     * @param maintainDataList
     * @param workbook
     */
    public static void getOtherExpenses(Sheet sheet,List<ErpCredit> erpCredits,List<MaintainData> maintainDataList,Workbook workbook){
        if (sheet!=null){
            CellStyle cellStyleFont = getCellStyleFont(workbook);
            CellStyle cellStyle = getCellStyle(workbook);
            OtherExpenses otherExpenses = null;
            XSSFRow row = (XSSFRow) sheet.createRow(2);
            XSSFCell cell = getViewCell(row,0);//编制单位
            cell.setCellValue(getCompany(erpCredits));
            cell = getViewCell(row,10);//编制日期
            cell.setCellValue(getCurrentDate());
            List<OtherExpenses> otherList = ExportUtilCalculate.getOtherExpenses(erpCredits, maintainDataList);
            for (int i = 0; i <otherList.size(); i++) {
                otherExpenses = otherList.get(i);
                row=(XSSFRow)sheet.createRow(i+5);
                int total = otherList.size()-1;

                cell = getViewCell(row,0,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(i+1);

                cell = getViewCell(row,1,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(otherExpenses.getProjectNumber());

                cell = getViewCell(row,2,i,total,cellStyle,cellStyleFont);
                cell.setCellValue("");

                cell = getViewCell(row,3,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(otherExpenses.getProjectName());

                cell = getViewCell(row,4,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(otherExpenses.getManagementFunds());
                setCellDoubleValue(cell, otherExpenses.getManagementFunds());


                cell = getViewCell(row,5,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(otherExpenses.getSupervisionFee());
                setCellDoubleValue(cell, otherExpenses.getSupervisionFee());

                cell = getViewCell(row,6,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(otherExpenses.getDesignFee());
                setCellDoubleValue(cell, otherExpenses.getDesignFee());

                cell = getViewCell(row,7,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(otherExpenses.getLoanInterest());
                setCellDoubleValue(cell, otherExpenses.getLoanInterest());

                cell = getViewCell(row,8,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(otherExpenses.getDamages());
                setCellDoubleValue(cell, otherExpenses.getDamages());

                cell = getViewCell(row,9,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(otherExpenses.getTotal());
                setCellDoubleValue(cell, otherExpenses.getTotal());

                cell = getViewCell(row,10,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(otherExpenses.getDeduction());
                setCellDoubleValue(cell, otherExpenses.getDeduction());

                cell = getViewCell(row,11,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(otherExpenses.getIncludingTax());
                setCellDoubleValue(cell, otherExpenses.getIncludingTax());
            }
        }

    }


    /**
     * 移交的资产总表04 写入数据
     * @param sheet
     * @param erpCredits
     * @param maintainDataList
     */
    public static void getSheetAssetsTotal(Sheet sheet,List<ErpCredit> erpCredits,List<MaintainData> maintainDataList){
        if (sheet!=null){
            XSSFRow row = (XSSFRow) sheet.getRow(2);
            XSSFCell cell = getViewCell(row,0);//编制单位
            cell.setCellValue(getCompany(erpCredits));
            cell = getViewCell(row,4);//编制日期
            cell.setCellValue(getCurrentDate());
            TheAssetsTotal theAssetsTotal = null;
            List<TheAssetsTotal> theAssetsTotals = ExportUtilCalculate.getTheAssetsTotal(erpCredits,maintainDataList);
            for (int i = 0; i < theAssetsTotals.size(); i++) {
                theAssetsTotal = theAssetsTotals.get(i);
                row = (XSSFRow) sheet.getRow((int)i+5);
                cell = row.getCell(2);
//                cell.setCellValue(theAssetsTotal.getBuildProject());
                setCellDoubleValue(cell, theAssetsTotal.getBuildProject());
                cell=row.getCell(3);
//                cell.setCellValue(theAssetsTotal.getIntallProject());
                setCellDoubleValue(cell, theAssetsTotal.getIntallProject());
                cell=row.getCell(4);
//                cell.setCellValue(theAssetsTotal.getEquipmentValue());
                setCellDoubleValue(cell, theAssetsTotal.getEquipmentValue());
                cell=row.getCell(5);
//                cell.setCellValue(theAssetsTotal.getCostSharing());
                setCellDoubleValue(cell, theAssetsTotal.getCostSharing());
                cell=row.getCell(6);
//                cell.setCellValue(theAssetsTotal.getDeliveryCostValue());
                setCellDoubleValue(cell, theAssetsTotal.getDeliveryCostValue());
            }
        }
    }

    /**
     * 04-1 写入数据
     * @param sheet
     * @param erpCredits
     * @param workbook
     */
    public static void getSheetLine2(Sheet sheet,List<ErpCredit> erpCredits,Workbook workbook){
        if (null!=sheet){
            CellStyle cellStyleFont=getCellStyleFont(workbook);
            CellStyle cellStyle = getCellStyle(workbook);

            XSSFRow row = (XSSFRow) sheet.getRow(2);
            XSSFCell cell = getViewCell(row,0);//编制单位
            cell.setCellValue(getCompany(erpCredits));
            cell = getViewCell(row,5);//编制日期
            cell.setCellValue(getCurrentDate());

            TransferOfPowerLine transferOfPower1 = null;
            List<TransferOfPowerLine> transferOfPower1s = ExportUtilCalculate.getTransFerPower1(erpCredits);
            for (int i = 0; i < transferOfPower1s.size(); i++) {
                transferOfPower1=transferOfPower1s.get(i);
                int total = transferOfPower1s.size()-1;//总数据条数
                row=(XSSFRow)sheet.createRow(i+5);

                cell = getViewCell(row,0,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(i+1);//序号


                cell = getViewCell(row,1,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower1.getPowerId());//项目号

                cell = getViewCell(row,2,i,total,cellStyle,cellStyleFont);
                cell.setCellValue("");//项目编号

                cell = getViewCell(row,3,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower1.getPowerName());//工程名称


                cell = getViewCell(row,4,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower1.getPowerNumberBars());//规模

                cell = getViewCell(row,5,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower1.getPowerAssetClass());//资产名称

                cell = getViewCell(row,6,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower1.getPowerArea());//所在地

                cell = getViewCell(row,7,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower1.getPowerDepartment());//使用保管部门

                cell = getViewCell(row,8,i,total,cellStyle,cellStyleFont);
                cell.setCellValue("km");//计量单位

                cell = getViewCell(row,9,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(transferOfPower1.getPowerTenKvLineLength());//线路长度或配变数量
                setCellDoubleValue(cell, transferOfPower1.getPowerTenKvLineLength());

                cell = getViewCell(row,10,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower1.getPowerTenKvCableType());//导线规格或配变容量

                cell = getViewCell(row,11,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(transferOfPower1.getPowerBuildFee());//建筑费用
                setCellDoubleValue(cell, transferOfPower1.getPowerBuildFee());

                cell = getViewCell(row,12,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(transferOfPower1.getPowerInstallFee());//安装费用
                setCellDoubleValue(cell, transferOfPower1.getPowerInstallFee());

                cell = getViewCell(row,13,i,total,cellStyle,cellStyleFont);
                cell.setCellValue("");//设备价值

                cell = getViewCell(row,14,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(transferOfPower1.getPowerStandInFee());//摊入费用
                setCellDoubleValue(cell, transferOfPower1.getPowerStandInFee());

                cell = getViewCell(row,15,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(transferOfPower1.getPowerDeliveredAssets());//交付使用资产价值
                setCellDoubleValue(cell, transferOfPower1.getPowerDeliveredAssets());

                cell = getViewCell(row,16,i,total,cellStyle,cellStyleFont);
                cell.setCellValue("");//附属设备价值

                cell = getViewCell(row,17,i,total,cellStyle,cellStyleFont);
                cell.setCellValue("");//资产代码
            }
        }
    }


    /**
     * 04-2 写入数据
     * @param sheet
     * @param erpCredits
     * @param maintainDataList
     * @param workbook
     */
    public static void getSheetEquip2(Sheet sheet,List<ErpCredit> erpCredits,List<MaintainData> maintainDataList,Workbook workbook){
        if (sheet!=null){
            CellStyle cellStyleFont=getCellStyleFont(workbook);
            CellStyle cellStyle = getCellStyle(workbook);


            XSSFRow row = (XSSFRow) sheet.getRow(2);
            XSSFCell cell = getViewCell(row,0);//编制单位
            cell.setCellValue(getCompany(erpCredits));
            cell = getViewCell(row,5);//编制日期
            cell.setCellValue(getCurrentDate());

            TransferOfEquipment transferOfPower2 = null;
            List<TransferOfEquipment> transferOfPower2s = ExportUtilCalculate.getTransferOfPower2(erpCredits,maintainDataList);
            for (int i = 0; i <transferOfPower2s.size(); i++) {
                transferOfPower2=transferOfPower2s.get(i);


                int total = transferOfPower2s.size()-1;//总数据条数
                row=(XSSFRow)sheet.createRow(i+5);

                cell = getViewCell(row,0,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(i+1);//序号

                cell = getViewCell(row,1,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower2.getPowerId());//项目号

                cell = getViewCell(row,2,i,total,cellStyle,cellStyleFont);
                cell.setCellValue("");//项目编号

                cell = getViewCell(row,3,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower2.getPowerName());//工程名称（配电网资产名称）

                cell = getViewCell(row,4,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower2.getPowerAssetName());//资产名称

                cell = getViewCell(row,5,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower2.getPowerAssetClass());//资产代码

                cell = getViewCell(row,6,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower2.getPowerArea());//线路起止地点或配变所在滴

                cell = getViewCell(row,7,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower2.getPowerDepartment());//保管部门

                cell = getViewCell(row,8,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower2.getPowerUnit());//计量单位

                cell = getViewCell(row,9,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower2.getPowerNumber());//配变数量

                cell = getViewCell(row,10,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower2.getPowerCapacity());//配变容量

                cell = getViewCell(row,11,i,total,cellStyle,cellStyleFont);
                cell.setCellValue("");//建筑费

                cell = getViewCell(row,12,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(transferOfPower2.getPowerInstallFee());//安装费
                setCellDoubleValue(cell, transferOfPower2.getPowerInstallFee());

                cell = getViewCell(row,13,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(transferOfPower2.getPowerValue());//设备价值
                setCellDoubleValue(cell, transferOfPower2.getPowerValue());

                cell = getViewCell(row,14,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(transferOfPower2.getPowerStandInFee());//摊入费用
                setCellDoubleValue(cell, transferOfPower2.getPowerDeliveredAssets());

                cell = getViewCell(row,15,i,total,cellStyle,cellStyleFont);
//                cell.setCellValue(transferOfPower2.getPowerDeliveredAssets());//交付使用资产价值
                setCellDoubleValue(cell, transferOfPower2.getPowerDeliveredAssets());

                cell = getViewCell(row,16,i,total,cellStyle,cellStyleFont);
                cell.setCellValue(transferOfPower2.getPoweRequipmentFee());//其中：附属设备价值
            }
        }
    }

    //移交资产—配电网资产一览表(线路)1
    public static void getSheetLine1(Sheet sheet, List<ErpCredit> erpCredits, XSSFWorkbook workbook){
       if (null!=sheet){
           CellStyle style=getCellStyleFont(workbook);
           CellStyle cellStyle = getCellStyle(workbook);
           XSSFRow row = (XSSFRow) sheet.createRow(4);
           XSSFCell cell = row.getCell(0);
           TransferOfPowerLine transferOfPower1 = null;
           List<TransferOfPowerLine> transferOfPower1s = ExportUtilCalculate.getTransFerPower1(erpCredits);
           for (int i = 0; i < transferOfPower1s.size(); i++) {
               transferOfPower1=transferOfPower1s.get(i);
               row = (XSSFRow) sheet.createRow((int)i+4);
               //线路第一行
               if (row.getCell(0)==null){
                   cell = row.createCell(0);
               }else {
                   cell = row.getCell(0);
               }
               cell.setCellValue(transferOfPower1.getPowerId());//添加项目编号
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }

               //线路第二行
               if (row.getCell(1)==null){
                   cell = row.createCell(1);
               }else {
                   cell = row.getCell(1);
               }
               cell.setCellValue(transferOfPower1.getPowerName());
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }
               //添加第3行
               if (row.createCell(2)==null){
                   cell = row.createCell(2);
               }else {
                   cell = row.getCell(2);
               }
               cell.setCellValue("-");
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }
               //添加第4行
               if (row.createCell(3)==null){
                   cell = row.createCell(3);
               }else {
                   cell = row.getCell(3);
               }
               cell.setCellValue(transferOfPower1.getPowerDepartment());
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }

               //第5行
               if (row.createCell(4)==null){
                   cell = row.createCell(4);
               }else {
                   cell = row.getCell(4);
               }
               cell.setCellValue(transferOfPower1.getPowerTenKvLineLength());
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }

               //第6行
               if (row.createCell(5)==null){
                   cell = row.createCell(5);
               }else {
                   cell=row.getCell(5);
               }
               cell.setCellValue(transferOfPower1.getPowerTenKvCableType());
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }

               //第7行
               if (row.createCell(6)==null){
                   cell = row.createCell(6);
               }else {
                   cell = row.getCell(6);
               }
               cell.setCellValue(transferOfPower1.getPowerBuildFee());
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }

               //第8行
               if (row.getCell(7)==null){
                   cell = row.createCell(7);
               }else {
                   cell = row.getCell(7);
               }
               cell.setCellValue(transferOfPower1.getPowerInstallFee());
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }

               //添加第9行
               if (row.getCell(8)==null){
                   cell = row.createCell(8);
               }else {
                   cell = row.getCell(8);
               }
               cell.setCellValue(transferOfPower1.getPowerStandInFee());
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }
               //添加滴10行
               if (row.getCell(9)==null){
                   cell = row.createCell(9);
               }else {
                   cell = row.getCell(9);
               }
               cell.setCellValue(transferOfPower1.getPowerDeliveredAssets());
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }

               //添加第11行
               if (row.getCell(10)==null){
                   cell = row.createCell(10);
               }else {
                   cell = row.getCell(10);
               }
               cell.setCellValue(transferOfPower1.getPoweRequipmentFee());
               cell.setCellStyle(cellStyle);
               if (i == transferOfPower1s.size() - 1){cell.setCellStyle(style); }

           }
       }
   }
   //移交资产—配电网资产一览表（设备）
   public static void getSheetEquip(Sheet sheet,List<ErpCredit> erpCredits,List<MaintainData> maintainDataList,Workbook workbook){
      if (sheet!=null){
          CellStyle style=getCellStyleFont(workbook);
          CellStyle cellStyle = getCellStyle(workbook);
          XSSFRow row = (XSSFRow) sheet.createRow(4);
          XSSFCell cell = row.getCell(0);
          TransferOfEquipment transferOfPower2 = null;
          List<TransferOfEquipment> transferOfPower2s = ExportUtilCalculate.getTransferOfPower2(erpCredits,maintainDataList);
          for (int i = 0; i < transferOfPower2s.size(); i++) {
              transferOfPower2=transferOfPower2s.get(i);
              row = (XSSFRow) sheet.createRow((int)i+4);
              //第一行
              if (row.getCell(0)==null){
                  cell = row.createCell(0);
              }else {
                  cell = row.getCell(0);
              }
              cell.setCellValue(transferOfPower2.getPowerId());
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }
              //第二行
              if (row.getCell(1)==null){
                  cell = row.createCell(1);
              }else {
                  cell =row.getCell(1);
              }
              cell.setCellValue(transferOfPower2.getPowerName());//配电网资产名称
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }
              //第三行
              if (row.getCell(2)==null){
                  cell = row.createCell(2);
              }else {
                  cell = row.getCell(2);
              }
              cell.setCellValue(transferOfPower2.getPowerArea());////线路起止地点或配变所在滴
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }

              //第四行
              if (row.getCell(3)==null){
                  cell = row.createCell(3);
              }else {
                  cell = row.getCell(3);
              }
              cell.setCellValue(transferOfPower2.getPowerDepartment());//保管部门
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }

              //第五行
              if (row.getCell(4)==null){
                  cell = row.createCell(4);
              }else {
                  cell = row.getCell(4);
              }
              cell.setCellValue(transferOfPower2.getPowerNumber());//配变数量
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }
              //第六行
              if (row.getCell(5)==null){
                  cell = row.createCell(5);
              }else {
                  cell = row.getCell(5);
              }
              cell.setCellValue(transferOfPower2.getPowerUnit());//计量单位
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }
              //第七行
              if (row.getCell(6)==null){
                  cell = row.createCell(6);
              }else {
                  cell = row.getCell(6);
              }
              cell.setCellValue(transferOfPower2.getPowerCapacity());//配变容量
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }
              //第8行
              if (row.getCell(7)==null){
                  cell = row.createCell(7);
              }else {
                  cell = row.getCell(7);
              }
              cell.setCellValue(transferOfPower2.getPowerInstallFee());//安装费
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }
              //第9行
              if (row.getCell(8)==null){
                  cell = row.createCell(8);
              }else {
                  cell = row.getCell(8);
              }
              cell.setCellValue(transferOfPower2.getPowerValue());//设备价值
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }
              //第10行
              if (row.getCell(9)==null){
                  cell = row.createCell(9);
              }else {
                  cell = row.getCell(9);
              }
              cell.setCellValue(transferOfPower2.getPowerStandInFee());//摊入费用
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }
              //第11行
              if (row.getCell(10)==null){
                  cell = row.createCell(10);
              }else {
                  cell = row.getCell(10);
              }
              cell.setCellValue(transferOfPower2.getPowerDeliveredAssets());//交付使用资产价值
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }
              //第12行
              if (row.getCell(11) == null){
                  cell = row.createCell(11);
              }else {
                  cell = row.getCell(11);
              }
              cell.setCellValue(transferOfPower2.getPoweRequipmentFee());//其中：附属设备价值
              cell.setCellStyle(cellStyle);
              if (i == transferOfPower2s.size() - 1){ cell.setCellStyle(style); }
          }
      }
   }

    /**
     * 设备材料清册写入数据
     * @param sheet
     * @param erpCredits
     * @param workbook
     */
    public static void getSheetEquipMaterial(Sheet sheet,List<ErpCredit> erpCredits,Workbook workbook){
        XSSFRow row = (XSSFRow) sheet.createRow(5);
        XSSFCell cell = row.getCell(0);
        CellStyle cellStyle = getCellStyle(workbook);//设备材料清册
        CellStyle cellStyle1 = getCellStyleAlign(workbook);
        MaterialEquipment materialEquipment = null;
        if (null!=sheet){
            List<MaterialEquipment> materialEquipments = ExportUtilCalculate.getSureMateralEquipment(erpCredits);
            for (int i = 0; i < materialEquipments.size(); i++) {
                materialEquipment = materialEquipments.get(i);
                row = (XSSFRow) sheet.createRow((int)i+5);
                //第一行
                if (row.getCell(0)==null){
                    cell = row.createCell(0);
                }else {
                    cell = row.getCell(0);
                }
                cell.setCellValue(i+1);//项目定义编号
                cell.setCellStyle(cellStyle1);//添加边框
                //第二行
                if (row.getCell(1)==null){
                    cell = row.createCell(1);
                }else {
                    cell = row.getCell(1);
                }
                cell.setCellValue(materialEquipment.getMeName());
                cell.setCellStyle(cellStyle);
                //第三行
                if (row.getCell(2)==null){
                    cell = row.createCell(2);
                }else {
                    cell = row.getCell(2);
                }
                cell.setCellValue(materialEquipment.getMeSpecifications());
                cell.setCellStyle(cellStyle);
                //第四行
                if (row.getCell(3)==null){
                    cell = row.createCell(3);
                }else {
                    cell = row.getCell(3);
                }
                cell.setCellValue(materialEquipment.getMeSupplierName());//供应单位制造
                cell.setCellStyle(cellStyle);
                //第五行
                if (row.getCell(4)==null){
                    cell = row.createCell(4);
                }else {
                    cell = row.getCell(4);
                }
                cell.setCellValue(materialEquipment.getMeUnit());////计量单位
                cell.setCellStyle(cellStyle);
                //第六行
                if (row.getCell(5)==null){
                    cell = row.createCell(5);
                }else {
                    cell = row.getCell(5);
                }
//                cell.setCellValue(materialEquipment.getMeNumber());////数量
                setCellDoubleValue(cell, materialEquipment.getMeNumber());
                cell.setCellStyle(cellStyle);
                //第七行
                if (row.getCell(6)==null){
                    cell = row.createCell(6);
                }else {
                    cell = row.getCell(6);
                }
//                cell.setCellValue(materialEquipment.getMeUnitPrice());////单价
                setCellDoubleValue(cell, materialEquipment.getMeUnitPrice());
                cell.setCellStyle(cellStyle);
                if (row.getCell(7)==null){
                    cell = row.createCell(7);
                }else {
                    cell = row.getCell(7);
                }
//                cell.setCellValue(materialEquipment.getMeAllPrice());////合计
                setCellDoubleValue(cell, materialEquipment.getMeAllPrice());
                cell.setCellStyle(cellStyle);
            }
        }
    }


    /**
     * 竣工工程决算表
     * @param sheet
     * @param erpCredits
     * @param maintainDataList
     */
    public static void getSheetSettlement(Sheet sheet,List<ErpCredit> erpCredits,List<MaintainData> maintainDataList){
        if (null!=sheet){
            XSSFRow row = (XSSFRow) sheet.getRow(2);
            XSSFCell cell = row.getCell(0);
            cell.setCellValue(getCompany(erpCredits));
            MCompletionProject mCompletionProject = ExportUtilCalculate.getMCompletionProject(erpCredits,maintainDataList);
            row = (XSSFRow)sheet.getRow(4);
            cell = row.getCell(5);
//            cell.setCellValue(mCompletionProject.getTransferAssets());
            setCellDoubleValue(cell, mCompletionProject.getTransferAssets());
            row = (XSSFRow) sheet.getRow(6);
            cell=row.getCell(5);
//            cell.setCellValue(mCompletionProject.getFixedAssets());
            setCellDoubleValue(cell, mCompletionProject.getFixedAssets());
            row = (XSSFRow) sheet.getRow(11);
            cell=row.getCell(5);
//            cell.setCellValue(mCompletionProject.getVatDeduction());
            setCellDoubleValue(cell, mCompletionProject.getVatDeduction());
            row = (XSSFRow)sheet.getRow(13);
            cell = row.getCell(5);
//            cell.setCellValue(mCompletionProject.getCompleted());
            setCellDoubleValue(cell, mCompletionProject.getCompleted());
            row = (XSSFRow) sheet.getRow(15);
            cell=row.getCell(2);
//            cell.setCellValue(mCompletionProject.getAppropriatedFunds());
            setCellDoubleValue(cell, mCompletionProject.getAppropriatedFunds());
        }
    }
    //合计行单元格样式
    public static CellStyle getCellStyleFont(Workbook workbook){
        XSSFFont font = (XSSFFont) workbook.createFont();
        font.setFontHeightInPoints((short) 12);//设置字体大小
        font.setBoldweight(HSSFFont.BOLDWEIGHT_BOLD);//粗体显示
        CellStyle style=workbook.createCellStyle();
        style.setBorderBottom(HSSFCellStyle.BORDER_THIN); //下边框
        style.setBorderLeft(HSSFCellStyle.BORDER_THIN);//左边框
        style.setBorderTop(HSSFCellStyle.BORDER_THIN);//上边框
        style.setBorderRight(HSSFCellStyle.BORDER_THIN);//右边框
        style.setFont(font);
        return style;
    }
    //单元格样式
    public static CellStyle getCellStyle(Workbook workbook){
        CellStyle style = workbook.createCellStyle();
        style.setBorderBottom(HSSFCellStyle.BORDER_THIN); //下边框
        style.setBorderLeft(HSSFCellStyle.BORDER_THIN);//左边框
        style.setBorderTop(HSSFCellStyle.BORDER_THIN);//上边框
        style.setBorderRight(HSSFCellStyle.BORDER_THIN);//右边框
        return style;
    }
    //设置边框
    public static CellStyle getCellStyleAlign(Workbook workbook){
        CellStyle style = workbook.createCellStyle();
        style.setAlignment(HSSFCellStyle.ALIGN_CENTER); // 居中
        style.setBorderBottom(HSSFCellStyle.BORDER_THIN); //下边框
        style.setBorderLeft(HSSFCellStyle.BORDER_THIN);//左边框
        style.setBorderTop(HSSFCellStyle.BORDER_THIN);//上边框
        style.setBorderRight(HSSFCellStyle.BORDER_THIN);//右边框
        return style;
    }

    public static List<String> getListSchOther(List<String> list,ScheduleOther scheduleOther){
        list.add(scheduleOther.getRequisitionSite());
        list.add(scheduleOther.getCompensationAcquisition());
        list.add(scheduleOther.getCleaningFees());
        list.add(scheduleOther.getStorageFee());
        list.add(scheduleOther.getCompensateFee());
        list.add(scheduleOther.getManagementFee());
        list.add(scheduleOther.getPreparationFee());
        list.add(scheduleOther.getItemManageFee());
        list.add(scheduleOther.getTheTenderFee());
        list.add(scheduleOther.getSupervisionFee());
        list.add(scheduleOther.getTechnicalFee());
        list.add(scheduleOther.getSurveyFee());
        list.add(scheduleOther.getDesignFee());
        list.add(scheduleOther.getDrawingBudgetFee());
        list.add(scheduleOther.getEvaluationFee());
        list.add(scheduleOther.getEconomicFee());
        list.add(scheduleOther.getInspectionFee());
        list.add(scheduleOther.getPreparationFee());
        list.add(scheduleOther.getBasicFee());
        list.add(scheduleOther.getReserveFee());
        list.add(scheduleOther.getTotalFee());
        return list;
    }

    /**
     * 获取编制日期
     * @return
     */
    public static String getCurrentDate(){
        Calendar calendar = Calendar.getInstance();
        return "编制日期："+calendar.get(Calendar.YEAR)+"年"+calendar.get(Calendar.MONTH)
                +"月"+calendar.get(Calendar.DATE)+"日";
    }

    /**
     * 获取编制单位
     * @param erpCredits
     * @return
     */
    public static String getCompany(List<ErpCredit> erpCredits){
        if(erpCredits==null||erpCredits.size()==0){
            return "";
        }
        ErpCredit credit = erpCredits.get(0);
        String profitCenter = credit.getProfitCenter();
        if("L010010501".equals(profitCenter)){
            return "编制单位：国网江苏省电力有限公司常州供电分公司";
        }else{
            return "";
        }
    }
}
